summaryrefslogtreecommitdiffstats
path: root/Discover.pm
diff options
context:
space:
mode:
authorMageia SVN-Git Migration <svn-git-migration@mageia.org>2011-05-14 01:22:07 +0100
committerMageia SVN-Git Migration <svn-git-migration@mageia.org>2011-05-14 01:22:07 +0100
commite0ada251ac68dc91192c7ec7d10f3a1d7784916a (patch)
tree225ed465e93c82ad37c2794144850635b395d594 /Discover.pm
parent5d4a18c95ac1ef5a657b5dcefd8a47e429d74058 (diff)
downloadmgaonline-e0ada251ac68dc91192c7ec7d10f3a1d7784916a.tar
mgaonline-e0ada251ac68dc91192c7ec7d10f3a1d7784916a.tar.gz
mgaonline-e0ada251ac68dc91192c7ec7d10f3a1d7784916a.tar.bz2
mgaonline-e0ada251ac68dc91192c7ec7d10f3a1d7784916a.tar.xz
mgaonline-e0ada251ac68dc91192c7ec7d10f3a1d7784916a.zip
Synthesized commit during git-svn import combining previous Mandriva history with Mageia.2.77.22
This commit consitsts of the following subversion commits: ------------------------------------------------------------------------ r1310 | dmorgan | 2011-05-14 01:22:07 +0100 (Sat, 14 May 2011) | 1 line Import cleaned mgaonline ------------------------------------------------------------------------
Diffstat (limited to 'Discover.pm')
-rw-r--r--Discover.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/Discover.pm b/Discover.pm
index e2dff77d..c6e5a34e 100644
--- a/Discover.pm
+++ b/Discover.pm
@@ -1,7 +1,7 @@
package Discover; # $Id$
################################################################################
# Part of Mandriva Online #
# Online service discovery library: #
# - autodetects nameservers and domains, #
# - and checks for DNS-declared Online service, #
@@ -30,7 +30,7 @@ use strict;
use Net::DNS;
use Data::Dumper;
use MDK::Common;
-use Config::Auto; # CPAN Module. Seems not to be part of Mandriva packages yet.
+use Config::Auto; # CPAN Module. Seems not to be part of Mageia packages yet.
use Switch;
use Log::Agent; # use settings from main file
@@ -67,7 +67,7 @@ sub commify_series {
sub search {
my $this = shift;
- logsay "searching for a locally declared Mandriva Online service";
+ logsay "searching for a locally declared Mageia Online service";
my $resolv = Config::Auto::parse('/etc/resolv.conf');
my $servicetype = '_mdvonline._http._tcp.bonjour.';
@@ -1,7 +1,7 @@
package Discover; # $Id$
################################################################################
-# Part of Mandriva Online #
+# Part of Mageia Online #
# Online service discovery library: #
# - autodetects nameservers and domains, #